#!/bin/sh
# Licensed Materials - Property of IBM
#
# 5725D70
#
# (C) Copyright IBM Corp. 2013 All rights reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

#
# Defaults
#
PROG_NAME=$0

if [ -z "$WAS_HOME" ]
then
	WAS_HOME=/opt/IBM/WebSphere
fi

if [ -z "$ISS_HOME" ]
then
	ISS_HOME=/opt/IBM/iss
fi

if [ -z "$IIT_HOME" ]
then
	IIT_HOME=$ISS_HOME/intelligentTransportation
fi

if [ -z "$IOT_HOME" ]
then
	IOT_HOME=$IIT_HOME/intelligentOperationsTransportation
fi

if [ -z "$APAR_HOME" ]
then
	APAR_HOME=.
fi

USAGE="$0 usage: $0 -user adminID -password password [-host hostname] [-port dmgrportnumber]\n\n
Defaults:\n
hostname:        localhost\n\n
dmgrportnumber:  8879\n\n
Other shell variables:\n
WAS_HOME:		$WAS_HOME\n
ISS_HOME:		$ISS_HOME\n
IIT_HOME:		$IIT_HOME\n
IOT_HOME:		$IOT_HOME\n
APAR_HOME:		$APAR_HOME
"

#
# Process args
#
while [ -n "$1" ]
do
	case $1 in
	"-host")
			shift
			HOST=1
			if [ -n "$1" ]
			then
			        HOST=$1
			        shift
			fi
			continue
	;;
	"-password")
			shift
			if [ -n "$1" ]
			then
			        PASSWORD=$1
			        shift
			fi
			continue
	;;

	"-user")
			shift
			if [ -n "$1" ]
			then
			        WS_ADMIN=$1
			        shift
			fi
			continue
	;;

	"-port")
			shift
			if [ -n "$1" ]
			then
			        PORT=$1
			        shift
			fi
			continue
	;;

	"-help")
			shift;
			echo -e $USAGE
			exit 1
	;;

	*)
			ARGS="$ARGS $1"
			shift

	esac
done

# Check arguments
if [ -z "$PASSWORD" ]
then
	echo "$PROG_NAME: No WebSphere administrator password specified"  1>&2
	echo -e $USAGE
	exit 2
fi

if [ -z "$WS_ADMIN" ]
then
	echo "$PROG_NAME: No WebSphere administrator specified"  1>&2
	echo -e $USAGE
	exit 3
fi

if [ -z "$HOST" ]
then
	HOST=localhost
fi

if [ -z "$PORT" ]
then
	PORT=8879
fi

$WAS_HOME/AppServer/bin/wsadmin.sh -conntype SOAP -host $HOST				\
		-port $PORT -user $WS_ADMIN -password $PASSWORD						\
		-c "\$AdminApp update trans_portlet_ear app {-operation update -contents $APAR_HOME/topology/tih/PORTAL/content/distribution/trans_portlet_ear.ear}"

$WAS_HOME/AppServer/bin/wsadmin.sh -conntype SOAP -host $HOST				\
		-port $PORT -user $WS_ADMIN -password $PASSWORD						\
		-c "\$AdminConfig save"

